ShapeHandler class

Constructors

ShapeHandler()

Properties

clipItems → List<ClipShapeItem>
final
hashCode → int
The hash code for this object.
no setterinherited
registeredGestures → Set<GestureType>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addShape(Shape shape) → void
handleGestureEvent(Gesture gesture, {ScrollController? scrollController, AxisDirection direction = AxisDirection.down}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited