PathShape class

Inheritance

Constructors

PathShape(Path path, {required Map<GestureType, Function> gestureMap, required Paint paint, HitTestBehavior? hitTestBehavior, PaintingStyle? paintStyleForTouch})

Properties

gestureCallbackMap → Map<GestureType, Function>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hitTestBehavior → HitTestBehavior
finalinherited
paint → Paint
finalinherited
path → Path
final
registeredGestures → Set<GestureType>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCallbackFromGesture(Gesture gesture) → Function
inherited
isInside(Offset p) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited