Shape class abstract

Implementers

Constructors

Shape({Paint? paint, Map<GestureType, Function>? gestureCallbackMap, HitTestBehavior? hitTestBehavior})

Properties

gestureCallbackMap → Map<GestureType, Function>
final
hashCode → int
The hash code for this object.
no setterinherited
hitTestBehavior → HitTestBehavior
final
paint → Paint
final
registeredGestures → Set<GestureType>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCallbackFromGesture(Gesture gesture) → Function
isInside(Offset p) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited